@@ -4,13 +4,13 @@
 
 .check_dataversion_string <- function(old_data_digest, new_data_digest) {
   oldwarn <- options("warn")$warn
-  options(warn = -1)
-  oldv <- strsplit(old_data_digest[["DataVersion"]], "\\.")
-  newv <- strsplit(new_data_digest[["DataVersion"]], "\\.")
-  oldv <- lapply(oldv, as.numeric)[[1]]
-  newv <- lapply(newv, as.numeric)[[1]]
+  suppressWarnings({
+    oldv <- strsplit(old_data_digest[["DataVersion"]], "\\.")
+    newv <- strsplit(new_data_digest[["DataVersion"]], "\\.")
+    oldv <- lapply(oldv, as.numeric)[[1]]
+    newv <- lapply(newv, as.numeric)[[1]]
+  })
   if (any(is.na(oldv)) | any(is.na(newv))) {
-    options(warn = oldwarn)
     .multilog_fatal(paste0(
       "Invalid DataVersion string found ",
       old_data_digest[["DataVersion"]],
@@ -30,41 +30,37 @@
 }
 
 .compare_digests <- function(old_digest, new_digest) {
-  valid <- ifelse(length(old_digest) != length(new_digest), FALSE, TRUE)
-  if (valid) {
-    for (i in names(new_digest)[-1L]) {
-      if (new_digest[[i]] != old_digest[[i]]) {
-        .multilog_warn(paste0(i, " has changed."))
-        valid <- FALSE
+  # Returns FALSE when any exisiting data has is changed, new data is added, or data is removed, else return TRUE.
+  # Use .mutlilog_warn when there is a change and multilog_debug when new data is added.
+
+  existed <- names(new_digest)[names(new_digest) %in% names(old_digest)]
+  added <- setdiff(names(new_digest), existed)
+  removed <- names(old_digest)[!names(old_digest) %in% names(new_digest)]
+  existed <- existed[existed != "DataVersion"]
+
+  if(length(existed) > 0){
+    changed <- names(new_digest)[ unlist(new_digest[existed]) != unlist(old_digest[existed]) ]
+    if(length(changed) > 0){
+      for(name in changed){
+        .multilog_warn(paste(name, "has changed."))
       }
-    }
-    if (!valid) {
       warning()
-    }
-  } else {
-    difference <- setdiff(names(new_digest), names(old_digest))
-    intersection <- intersect(names(new_digest), names(old_digest))
-    # No existing or new objects are changed
-    if (length(difference) == 0) {
-      valid <- TRUE
-    } else {
-      # some new elements exist
-      valid <- FALSE
-      for (i in difference) {
-        .multilog_debug(paste0(i, " added."))
-      }
-    }
-    for (i in intersection) {
-      if (new_digest[[i]] != old_digest[[i]]) {
-        .multilog_debug(paste0(i, " changed"))
-        # some new elements are not the same
-        valid <- FALSE
-      }
+      return(FALSE)
     }
   }
-  return(valid)
-}
 
+  for(name in removed){
+    .multilog_debug(paste(name, "was removed."))
+    return(FALSE)
+  }
+
+  for(name in added){
+    .multilog_debug(paste(name, "was added."))
+    return(FALSE)
+  }
+
+  return(TRUE)
+};
 
 .combine_digests <- function(new, old) {
   intersection <- intersect(names(new), names(old))
