@@ -10,12 +10,11 @@ test_that("news file is created", {
     force = TRUE,
     r_object_names = c("cars_over_20")
   )
-  options(DataPackageR_interact = FALSE)
   package_build(file.path(tempdir(), "subsetCars"))
   expect_equal(readLines(file.path(tempdir(), "subsetCars", "NEWS.md"))[3], "Package built in non-interactive mode") # nolint
   unlink(file.path(tempdir(), "subsetCars"),
     recursive = TRUE,
     force = TRUE
   )
-  expect_equal(DataPackageR:::.prompt_user_for_change_description(interact = FALSE), "Package built in non-interactive mode") # nolint
+  expect_equal(DataPackageR:::.prompt_user_for_change_description(), "Package built in non-interactive mode") # nolint
 })
